@@ -1,6 +1,6 @@
 census <-
-function(ip.address,session) {
-    census.url<-paste(session$ip,"combined.json?ip=",ip.address,"&apikey=",session$api.key,sep="")
+function(ip.address) {
+    census.url<-paste(.InfochimpsEnv$data$ip,"combined.json?ip=",ip.address,"&apikey=",.InfochimpsEnv$data$api.key,sep="")
     census.get<-getURL(census.url)
     census.data<-fromJSON(census.get)
     if(is.null(census.data$error)) {
